// Copyright (c) 2023 ESWIN Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef AUDIO_SAMPLES_SAMPLE_COMM_H__
#define AUDIO_SAMPLES_SAMPLE_COMM_H__

#include <pthread.h>

#include "es_common.h"
#include "es_comm_sys.h"
#include "es_comm_adec.h"
#include "es_comm_aenc.h"
#include "es_comm_aio.h"
#include "es_defines.h"
// #include "es_comm_hdmi.h"

#ifdef __cplusplus
#if __cplusplus
extern "C" {
#endif
#endif /* End of #ifdef __cplusplus */

/*******************************************************
    macro define
*******************************************************/
#define FILE_NAME_LEN 128
#define SAMPLE_AUDIO_AI_CARD 0
#define SAMPLE_AUDIO_AO_CARD 0
#define SAMPLE_AUDIO_HDMI_CARD_DVB 1
#define SAMPLE_AUDIO_HDMI_CARD_EVB 2
#define SAMPLE_AUDIO_HDMI_CARD 2
#define SAMPLE_AUDIO_AI_DEV 0
#define SAMPLE_AUDIO_AO_DEV 0
#define SAMPLE_AUDIO_HDMI_DEV 0
#define SAMPLE_AUDIO_PTNUMPERFRM 480
#define SAMPLE_AUDIO_MAX_PTNUMPERFRM 2048

/*******************************************************
    function announce
*******************************************************/
ES_S32 SAMPLE_COMM_AUDIO_AiSetting(AUDIO_CARD AiCard, AUDIO_DEV AiDev, const AUDIO_SAVE_FILE_INFO_S* FileInfo,
                                   ES_BOOL bSaveFile, AUDIO_TRACK_MODE_E enTrackMode, ES_BOOL bTrackMode);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev, FILE* pAiFd);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAo(AUDIO_CARD AoCardId, AUDIO_DEV AoDev, AIO_ATTR_S* pstAioAttr, FILE* pAoFd);
ES_S32 SAMPLE_COMM_AUDIO_CreateTrdAenc(AENC_CHN AencChn, AIO_ATTR_S* pstAioAttr, FILE* pInFd, FILE* pOutFd);
ES_S32 SAMPLE_COMM_AUDIO_CreateTrdAdec(ADEC_CHN AdecChn, FILE* pInFd, FILE* pOutFd);
ES_S32 SAMPLE_COMM_AUDIO_CreateTrdAdecGetData(ADEC_CHN AdecChn, FILE* pInFd, FILE* pOutFd, AUDIO_CARD AoCardId,
                                              AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAiAo(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AUDIO_CARD AoCard, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAiAenc(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AENC_CHN AeChn);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAencAdec(AENC_CHN AeChn, ADEC_CHN AdChn, FILE* pAecFd);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdFileAdec(ADEC_CHN AdChn, FILE* pAdcFd);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAiVolCtrl(AUDIO_CARD AiCard, AUDIO_DEV AiDev);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAoVolCtrl(AUDIO_CARD AoCardId, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_CreatTrdAoPauseCtrl(AUDIO_CARD AoCardId, AUDIO_DEV AoDev);

ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAo(AUDIO_CARD AoCardId, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAenc(AENC_CHN AencChn);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAdec(ADEC_CHN AdecChn);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAdecGetData(ADEC_CHN AdecChn);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAencAdec(AENC_CHN AeChn);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdFileAdec(ADEC_CHN AdChn);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAiVolCtrl(AUDIO_CARD AiCard, AUDIO_DEV AiDev);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAoVolCtrl(AUDIO_CARD AoCardId, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_DestroyTrdAoPauseCtrl(AUDIO_CARD AoCardId, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_DestroyAllTrd(void);

ES_S32 SAMPLE_COMM_AUDIO_AoBindAdec(AUDIO_CARD AoCardId, AUDIO_DEV AoDev, ADEC_CHN AdChn);
ES_S32 SAMPLE_COMM_AUDIO_AoUnbindAdec(AUDIO_CARD AoCardId, AUDIO_DEV AoDev, ADEC_CHN AdChn);
ES_S32 SAMPLE_COMM_AUDIO_AoBindAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AUDIO_CARD AoCard, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_AoUnbindAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AUDIO_CARD AoCard, AUDIO_DEV AoDev);
ES_S32 SAMPLE_COMM_AUDIO_AencBindAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AENC_CHN AeChn);
ES_S32 SAMPLE_COMM_AUDIO_AencUnbindAi(AUDIO_CARD AiCard, AUDIO_DEV AiDev, AENC_CHN AeChn);

ES_S32 SAMPLE_COMM_AUDIO_StartAi(AUDIO_CARD AiCard, AUDIO_DEV AiDevId, AIO_ATTR_S* pstAioAttr,
                                 AUDIO_SAMPLE_RATE_E enOutSampleRate, ES_BOOL bResampleEn, ES_VOID* pstAiVqeAttr,
                                 ES_U32 u32AiVqeType);
ES_S32 SAMPLE_COMM_AUDIO_StopAi(AUDIO_CARD AiCard, AUDIO_DEV AiDevId, ES_BOOL bResampleEn, ES_BOOL bVqeEn);

ES_S32 SAMPLE_COMM_AUDIO_AoSetting(AUDIO_CARD AoCardId, AUDIO_DEV AoDev, const AUDIO_SAVE_FILE_INFO_S* FileInfo,
                                   ES_BOOL bSaveFile, AUDIO_TRACK_MODE_E enTrackMode, ES_BOOL bTrackMode);
ES_S32 SAMPLE_COMM_AUDIO_StartAo(AUDIO_CARD AoCardId, AUDIO_DEV AoDevId, ES_S32 s32AoChnCnt, AIO_ATTR_S* pstAioAttr,
                                 AUDIO_SAMPLE_RATE_E enInSampleRate, ES_BOOL bResampleEn);
ES_S32 SAMPLE_COMM_AUDIO_StartAoWithVQE(AUDIO_CARD AoCardId, AUDIO_DEV AoDevId, ES_S32 s32AoChnCnt,
                                        AIO_ATTR_S* pstAioAttr, AUDIO_SAMPLE_RATE_E enInSampleRate, ES_BOOL bResampleEn,
                                        AO_VQE_CONFIG_S* pstAoVqeAttr);
ES_S32 SAMPLE_COMM_AUDIO_StopAo(AUDIO_CARD AoCardId, AUDIO_DEV AoDevId, ES_S32 s32AoChnCnt, ES_BOOL bResampleEn);
ES_S32 SAMPLE_COMM_AUDIO_StartAenc(ES_S32 s32AencChn, AIO_ATTR_S* pstAioAttr, PAYLOAD_TYPE_E enType);
ES_S32 SAMPLE_COMM_AUDIO_StopAenc(ES_S32 AeChn);
ES_S32 SAMPLE_COMM_AUDIO_StartAdec(ADEC_CHN AdChn, PAYLOAD_TYPE_E enType);
ES_S32 SAMPLE_COMM_AUDIO_StopAdec(ADEC_CHN AdChn);

#ifdef __cplusplus
#if __cplusplus
}
#endif
#endif /* End of #ifdef __cplusplus */

#endif /* End of #ifndef AUDIO_SAMPLES_SAMPLE_COMM_H__ */
